## START: Set by rpmautospec
## (rpmautospec version 0.5.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Not yet packaged: python3dist(pettingzoo)
%bcond gymnasium 0

%ifarch x86_64 aarch64
%global arch_has_torch 1
%endif
%bcond torch 0%{?arch_has_torch:1}

Name:           python-ratinabox
Version:        1.12.0
Release:        %autorelease
Summary:        A package for simulating motion and ephys data in continuous environments

# SPDX
License:        MIT
URL:            https://github.com/TomGeorge1234/RatInABox
# If we switched to the GitHub archive from the PyPI sdist, we could add a
# CITATION.bib file, a demos/ directory, and Sphinx-generated documentation;
# however, we consider this not worthwhile, especially since the demos are so
# large that it is doubtful whether it is worth packaging them.
Source:         %{pypi_source ratinabox}

# The package is arched so that the BR and weak dependency on python-torch can
# be conditionalized. It does not contain compiled machine code, so there are
# no debugging symbols.
%global debug_package %{nil}

BuildRequires:  python3-devel

# Run tests in parallel (“-n auto”)
BuildRequires:  %{py3_dist pytest-xdist}
%if %{with torch}
BuildRequires:  %{py3_dist torch}
%endif

%global common_description %{expand:
RatInABox is a toolkit for generating locomotion trajectories and complementary
neural data for spatially and/or velocity selective cell types in complex
continuous environments.}

%description %{common_description}


%package -n     python3-ratinabox
Summary:        %{summary}

%if %{with torch}
Recommends:     %{py3_dist torch}
%endif

%description -n python3-ratinabox %{common_description}


%if %{with gymnasium}
%pyproject_extras_subpkg -n python3-ratinabox gymnasium
%endif


%prep
%autosetup -n ratinabox-%{version}


%generate_buildrequires
%pyproject_buildrequires -x test%{?with_gymnasium:,gymnasium}


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l ratinabox


%check
# Let’s do this in addition to running the tests, so we can be aware of any
# issues in contribs that may not be tested.
%{pyproject_check_import \
    %{?!with_torch:-e '*.contribs.NeuralNetworkNeurons'} \
    %{?!with_gymnasium:-e '*.contribs.TaskEnvironment'} }

%if %{without gymnasium}
# Indirectly (via ratinabox/contribs/TaskEnvironment.py) requires pettingzoo:
ignore="${ignore-} --ignore=tests/test_taskenv.py"
%endif
%pytest ${ignore-} -v -n auto


%files -n python3-ratinabox -f %{pyproject_files}
%doc README.md


%changelog
## START: Generated by rpmautospec
* Fri Feb 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-2
- Conditionalize python-torch dependencies on architecture
- The package is therefore no longer noarch.

* Fri Feb 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.12.0-1
- Update to 1.12.0 (close RHBZ#2262438)

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Dec 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.11.4-3
- Assert that %%pyproject_files contains a license file

* Sun Dec 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.11.4-2
- F40+: Enable BR and weak dependency on PyTorch

* Thu Dec 07 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.11.4-1
- Update to 1.11.4 (close RHBZ#2253380)

* Tue Dec 05 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.11.2-1
- Update to 1.11.2 (close RHBZ#2253008)

* Tue Nov 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.11.1-1
- Update to 1.11.1 (close RHBZ#2250734)

* Mon Nov 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.11.0-1
- Update to 1.11.0 (close RHBZ#2249382)

* Sun Oct 22 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.10.2-1
- Update to 1.10.2 (close RHBZ#2245423)

* Thu Oct 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.10.0-1
- Update to 1.10.0 (close RHBZ#2243563)

* Mon Sep 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.9.3-1
- Update to 1.9.3 (close RHBZ#2239469)

* Fri Sep 08 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.9.2-1
- Update to 1.9.2 (close RHBZ#2238000)

* Wed Aug 30 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.9.1-1
- Update to 1.9.1 (close RHBZ#2236083)

* Wed Aug 23 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.9.0-2
- Run an import-only “smoke test” *in addition to* the test suite

* Wed Aug 23 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.9.0-1
- Update to 1.9.0 (close RHBZ#2233318)

* Tue Aug 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.8.0-1
- Update to 1.8.0 (close RHBZ#2232115)

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 04 2023 Python Maint <python-maint@redhat.com> - 1.7.1-2
- Rebuilt for Python 3.12

* Fri Jun 16 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.7.1-1
- Update to 1.7.1 (close RHBZ#2213014)

* Mon May 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.6.3-1
- Initial package (close RHBZ#2209193)
## END: Generated by rpmautospec
